@@ -37,22 +37,18 @@
 **  
 ******************************************************************************/
 
-
-
-
-
+#include <config.h>
 #include "emboss.h"
 
 
 
 
-
-
 /******************************************************************************
 **
 ** PROTOTYPES  
 **
 ******************************************************************************/
+
 static AjBool domainseqs_AlignDomain(AjPSeq sp_seq, 
 				     AjPSeq pdb_seq, 
 				     AjPMatrixf matrix, 
@@ -93,8 +89,8 @@ int main(int argc, char **argv)
     ajint      end        = 0;    /* End of the domain inthe swissprot 
 				     sequence.                               */
     
-    float      gapopen    = 0.0;  /* Gap insertion penalty.                  */
-    float      gapextend  = 0.0;  /* Gap extension penalty.                  */
+    float      gapopen    = 0.0F; /* Gap insertion penalty.                  */
+    float      gapextend  = 0.0F; /* Gap extension penalty.                  */
  
     AjPStr     msg        = NULL; /* String used for messages.               */
     AjPDir     dpdb_path  = NULL; /* Path of dpdb (clean domain) files.      */
@@ -125,9 +121,12 @@ int main(int argc, char **argv)
     AjBool     getswiss   = ajFalse; /* Whether to retrieve swissprot 
 				       sequences for the domains.            */
     
-    ajint      type       = 0;   /* Type of domain (ajSCOP or ajCATH) in the 
-				    DCF file.                                */
-
+    AjEDomainType type = ajEDomainTypeNULL; /* Type of domain
+                                            ** (ajEDomainTypeSCOP or
+                                            ** ajEDomainTypeCATH) in the 
+                                            ** DCF file.
+                                            */
+    AjPPdbtosp pdbtosp = NULL;
     
     /* Initialise strings, lists,  etc */
     msg        = ajStrNew();
@@ -137,13 +136,13 @@ int main(int argc, char **argv)
     db         = ajStrNew();
     sp_dom_seq = ajStrNew();
 
-
+    embInitPV("domainseqs",argc,argv,"DOMAINATRIX",VERSION);
 
     /* Read data from acd */
-    embInitP("domainseqs",argc,argv,"DOMAINATRIX");
 
-    domain_inf    = ajAcdGetInfile("dcfinfile");
-    getswiss    = ajAcdGetToggle("getswiss");
+    domain_inf = ajAcdGetInfile("dcfinfile");
+    getswiss   = ajAcdGetToggle("getswiss");
+    
     if(getswiss)
     {
 	pdbtosp_inf = ajAcdGetInfile("pdbtospfile");
@@ -151,12 +150,11 @@ int main(int argc, char **argv)
 	gapopen     = ajAcdGetFloat("gapopen");
 	gapextend   = ajAcdGetFloat("gapextend");
     }
-    domain_outf   = ajAcdGetOutfile("dcfoutfile");
+    domain_outf = ajAcdGetOutfile("dcfoutfile");
     dpdb_path   = ajAcdGetDirectory("dpdbdir");
     errf        = ajAcdGetOutfile("logfile");
 
 
-
     /* Set up the pdbtosp object list. */
     if(getswiss)
 	list = ajPdbtospReadAllNew(pdbtosp_inf);
@@ -173,11 +171,11 @@ int main(int argc, char **argv)
 	ajFmtPrint("//\n%-15S\n", ajDomainGetId(domain));  
 	
 
-	if(!(dpdb_inf=ajFileNewDirF(dpdb_path, dpdb_name)))
+	if(!(dpdb_inf=ajFileNewListinDirPre(dpdb_path, dpdb_name)))
 	{
 	    ajStrAssignS(&msg, dpdb_name);
 	    ajStrAppendC(&msg, ".");
-	    ajStrAppendS(&msg,ajDirExt(dpdb_path));
+	    ajStrAppendS(&msg,ajDirGetExt(dpdb_path));
 	    ajFmtPrintF(errf, "%-15s\n", "FILE_OPEN");  
 	    ajWarn("Could not open ccf file %S", msg);
 	    ajDomainDel(&domain);
@@ -205,7 +203,7 @@ int main(int argc, char **argv)
 	ajStrAssignS(&pdb_seq->Seq,dpdb_seq);
 	
 	/* Add pdb sequence to the domain structure. */
-	if((domain->Type == ajSCOP))
+	if((domain->Type == ajEDomainTypeSCOP))
 	    ajStrAssignS(&domain->Scop->SeqPdb, dpdb_seq);
 	else
 	    ajStrAssignS(&domain->Cath->SeqPdb, dpdb_seq);
@@ -228,7 +226,8 @@ int main(int argc, char **argv)
 	   comprised of segments. */
 	if(ajDomainGetN(domain) != 1)
 	{
-	    ajWarn("Will not retrieve swissprot sequence for segmented domain %S\n",
+	    ajWarn("Will not retrieve swissprot sequence for "
+                   "segmented domain %S\n",
 		   dpdb_name);
 	    ajFmtPrintF(errf, "%-15s\n", "SEGMENTED_DOMAIN_NO_SP_SEQ");  
 	    ajDomainWrite(domain_outf,domain);
@@ -253,7 +252,7 @@ int main(int argc, char **argv)
 	}
 
 	/* Add the accession number to the domain structure. */
-	if((domain->Type == ajSCOP))
+	if((domain->Type == ajEDomainTypeSCOP))
 	    ajStrAssignS(&domain->Scop->Acc,acc);
 	else
 	    ajStrAssignS(&domain->Cath->Acc,acc);
@@ -264,7 +263,7 @@ int main(int argc, char **argv)
 	ajStrAssignC(&db, "swissprot-acc:");
 	ajStrAppendS(&db, acc);
 
-	if(!(ajSeqGetFromUsa(db,ajTrue,&sp_seq)))
+	if(!(ajSeqGetFromUsa(db,ajTrue,sp_seq)))
         {
             ajFmtPrintF(errf, "%-15s\n", "ENTRY_NOT_FOUND_IN_SW");
             ajDomainWrite(domain_outf,domain);
@@ -277,13 +276,13 @@ int main(int argc, char **argv)
         }
         else
 	{
-	    if((domain->Type == ajSCOP))
+	    if((domain->Type == ajEDomainTypeSCOP))
 		ajStrAssignS(&domain->Scop->Spr,sp_seq->Name);
 	    else
 		ajStrAssignS(&domain->Cath->Spr,sp_seq->Name);
 	}
 	
-	if((domain->Type == ajSCOP))
+	if((domain->Type == ajEDomainTypeSCOP))
 	    ajStrAssignS(&domain->Scop->Spr,sp_seq->Name);
 	else
 	    ajStrAssignS(&domain->Cath->Spr,sp_seq->Name);
@@ -296,7 +295,7 @@ int main(int argc, char **argv)
 	    start = ajStrFindS(sp_seq->Seq,dpdb_seq);
 	    end = start + dpdb_seq->Len - 1;
 
-	    if((domain->Type == ajSCOP))
+	    if((domain->Type == ajEDomainTypeSCOP))
 	    {
 		domain->Scop->Startd = start+1;
 		domain->Scop->Endd = end+1;
@@ -315,7 +314,7 @@ int main(int argc, char **argv)
 	{
 	    ajFmtPrintF(errf, "%-15s\n", "ALIGNMENT_NECESSARY"); 
 
-	    if((domain->Type == ajSCOP))
+	    if((domain->Type == ajEDomainTypeSCOP))
 	    {
 		domain->Scop->Startd = (start+1);
 		domain->Scop->Endd = end;
@@ -334,7 +333,7 @@ int main(int argc, char **argv)
 	   write to domain structure. */
 	ajStrAssignSubS(&sp_dom_seq, sp_seq->Seq, start, end);
 
-	if((domain->Type == ajSCOP))
+	if((domain->Type == ajEDomainTypeSCOP))
 	    ajStrAssignS(&domain->Scop->SeqSpr,sp_dom_seq);
 	else
 	    ajStrAssignS(&domain->Cath->SeqSpr,sp_dom_seq);
@@ -354,8 +353,12 @@ int main(int argc, char **argv)
     }
     
 
-    
     /* Memory management.  */
+
+    while(ajListPop(list, (void**) &pdbtosp))
+        ajPdbtospDel(&pdbtosp);
+    ajListFree(&list);
+
     ajDirDel(&dpdb_path);
     ajMatrixfDel(&matrix);
     ajStrDel(&msg);
@@ -368,16 +371,19 @@ int main(int argc, char **argv)
 	ajFileClose(&pdbtosp_inf);
     ajFileClose(&domain_outf);	    
     
+    embExit();
 
-    ajExit();
     return 0;
 }
 
+
+
+
 /* @funcstatic domainseqs_AlignDomain *****************************************
 **
 ** Align the pdb sequence to the full length swissprot sequence using Needleman 
-** and Wunsch (adapted to find location (start & end) of pdb sequence in swissprot
-** sequence).
+** and Wunsch (adapted to find location (start & end) of pdb sequence in
+** swissprot sequence).
 **
 ** @param [r] sp_seq    [AjPSeq]     Swissprot sequence object 
 ** @param [r] pdb_seq   [AjPSeq]     Pdb sequence object 
@@ -390,6 +396,7 @@ int main(int argc, char **argv)
 ** @return [AjBool] ajTrue on success
 ** @@
 ******************************************************************************/
+
 static AjBool domainseqs_AlignDomain(AjPSeq sp_seq,
 				     AjPSeq pdb_seq, 
 				     AjPMatrixf matrix, 
@@ -398,7 +405,6 @@ static AjBool domainseqs_AlignDomain(AjPSeq sp_seq,
 				     ajint* start, 
 				     ajint* end)
 {
-
     ajint      start1  = 0;	    /* Start of seq 1, passed but not used. */
     ajint      start2  = 0;	    /* Start of seq 2, passed but not used. */
     ajint      maxarr  = 300;       /* Initial size for matrix. */
@@ -435,7 +441,6 @@ static AjBool domainseqs_AlignDomain(AjPSeq sp_seq,
 	return ajFalse;
     }
     
-    
     /*Intitialise some variables*/
     AJCNEW(path, maxarr);
     AJCNEW(compass, maxarr);
@@ -443,11 +448,11 @@ static AjBool domainseqs_AlignDomain(AjPSeq sp_seq,
     m = ajStrNew();    
     n = ajStrNew();    
 
-    gapopen   = ajRoundF(gapopen,8);
-    gapextend = ajRoundF(gapextend,8);
+    gapopen   = ajRoundFloat(gapopen,8);
+    gapextend = ajRoundFloat(gapextend,8);
 
-    sub = ajMatrixfArray(matrix);
-    cvt = ajMatrixfCvt(matrix);
+    sub = ajMatrixfGetMatrix(matrix);
+    cvt = ajMatrixfGetCvt(matrix);
 
 
     begina  = ajSeqGetBegin(sp_seq)+ajSeqGetOffset(sp_seq);
@@ -474,15 +479,15 @@ static AjBool domainseqs_AlignDomain(AjPSeq sp_seq,
     
     
     /* Call alignment functions. */
-    embAlignPathCalc(p,q,lena,lenb, gapopen,gapextend,path,sub,cvt,
+    score = embAlignPathCalc(p,q,lena,lenb, gapopen,gapextend,path,sub,cvt,
 		     compass,show);
 
-    score =  embAlignScoreNWMatrix(path,sp_seq,pdb_seq,sub,cvt,lena, 
-				   lenb,gapopen,compass,gapextend,
-				   &start1,&start2);
+    /*score =  embAlignScoreNWMatrix(path,compass,gapopen,gapextend,
+                                   sp_seq,pdb_seq,lena,lenb,
+				   sub,cvt,&start1,&start2);*/
 
     embAlignWalkNWMatrix(path,sp_seq,pdb_seq,&m,&n,lena,lenb,&start1,
-			 &start2,gapopen,gapextend,cvt,compass,sub);
+			 &start2,gapopen,gapextend,compass);
 
     embAlignCalcSimilarity(m,n,sub,cvt,lena,lenb,&id,&sim,&idx, &simx);
 
@@ -491,23 +496,18 @@ static AjBool domainseqs_AlignDomain(AjPSeq sp_seq,
     domainseqs_FindDomainLimits(sp_seq, pdb_seq, m, n, start1, start2,	
 			   gapopen, gapextend, score, matrix, begina,
 			   beginb, start, end);
-   
     
-    
-    /* Tidy up. */
     AJFREE(compass);
     AJFREE(path);
     ajStrDel(&m);
     ajStrDel(&n);
     
-    /* Bye Bye. */
     return ajTrue;
 }    
 
 
 
 
-
 /* @funcstatic domainseqs_FindDomainLimits ************************************
 **
 ** Calculates the start and end of the alignment relative to the swissprot 
@@ -550,27 +550,35 @@ static AjBool domainseqs_FindDomainLimits(AjPSeq sp_seq,
     AjPSeq res1       = NULL;
     AjPSeq res2       = NULL;
 
-    ajint end1;
-    ajint end2;
+    ajint end1        = 0;
+    ajint end2        = 0;
 
     AjPStr fa         = NULL;
     AjPStr fb         = NULL;
     AjPSeqset seqset  = NULL;
 
-    ajint maxlen;
-    ajint i;
-    ajint alen;
-    ajint blen;
-    ajint apos;
-    ajint bpos;
-    ajint nc;
+    ajint maxlen      = 0;
+    ajint i           = 0;
+    ajint alen        = 0;
+    ajint blen        = 0;
+    ajint apos        = 0;
+    ajint bpos        = 0;
+    ajint nc          = 0;
 
-    const char* a;
-    const char* b;
+    const char* a     = NULL;
+    const char* b     = NULL;
 
     ajint no_gaps_sp  = 0;   /* The number of gaps in the swissprot sequence. */
-    ajint no_gaps_pdb = 0;   /* The number of gaps in the pdb sequence. */
-    
+/*  ajint no_gaps_pdb = 0; *//* The number of gaps in the pdb sequence. */
+
+    /* TODO: The following parameters are unused. */
+    (void) gapopen;
+    (void) gapextend;
+    (void) score;
+    (void) matrix;
+    (void) begina;
+    (void) beginb;
+
     ajDebug("embAlignReportGlobal %d %d\n", start1, start2);
     ajDebug("  sp_seq: '%S' \n", ajSeqGetSeqS(sp_seq));
     ajDebug("  pdb_seq: '%S' \n", ajSeqGetSeqS(pdb_seq));
@@ -669,14 +677,13 @@ static AjBool domainseqs_FindDomainLimits(AjPSeq sp_seq,
     end1 = start1 - ajStrCalcCountK(m, '-') + ajStrGetLen(m);
     end2 = start2 - ajStrCalcCountK(n, '-') + ajStrGetLen(n);
 
-    /* Find the domain boundries form the sequence alignment. */
+    /* Find the domain boundaries from the sequence alignment. */
 
     no_gaps_sp  = (alen + (end1 - ajStrGetLen(sp_seq->Seq)));
-    no_gaps_pdb = (blen + (end2 - ajStrGetLen(pdb_seq->Seq)));
+    /*no_gaps_pdb = (blen + (end2 - ajStrGetLen(pdb_seq->Seq)));*/
     
     *end = (((*start + (end2-start2)) - no_gaps_sp));
    
-
     ajStrDel(&fa);
     ajStrDel(&fb);
     ajSeqsetDel(&seqset);
@@ -685,17 +692,3 @@ static AjBool domainseqs_FindDomainLimits(AjPSeq sp_seq,
 
     return ajTrue;
 }
-
-
-
-
-
-
-
-
-
-
-
-
-
-
